Skip to main content Crate codex_utils_pty Copy item path Source pub use pipe::spawn_process as spawn_pipe_process;pub use pipe::spawn_process_no_stdin as spawn_pipe_process_no_stdin;pub use pty::conpty_supported ;pub use pty::spawn_process as spawn_pty_process;pipe process_group Process-group helpers shared by pipe/pty and shell command execution. pty ProcessDriver Driver-backed process adapter used by integrations with their own process transport.
Driver-backed process handles for non-standard spawn backends. ProcessHandle Handle for interacting with a spawned process (PTY or pipe).
Handle for driving an interactive process (PTY or pipe). SpawnedProcess Bundle of process handles plus split output and exit receivers returned by spawn helpers.
Return value from PTY or pipe spawn helpers. TerminalSize Terminal size in character cells used for PTY spawn and resize operations. ProcessSignal Process signal supported by spawned-process handles. DEFAULT_OUTPUT_BYTES_CAP combine_output_receivers Combine stdout/stderr receivers into a single broadcast receiver.
Combine split stdout/stderr receivers into a single broadcast receiver. spawn_from_driver Adapt an externally-driven process into the standard spawned-process handle.
Build a SpawnedProcess from a driver that supplies stdin/output/exit channels. ExecCommandSession Backwards-compatible alias for ProcessHandle. SpawnedPty Backwards-compatible alias for SpawnedProcess.